

set -ex



test -f $PREFIX/lib/libgtest${SHLIB_EXT}
test ! -f $PREFIX/lib/libgtest.a
pkg-config --print-errors --exact-version "1.14.0" gtest
test -f $PREFIX/lib/libgtest_main${SHLIB_EXT}
test ! -f $PREFIX/lib/libgtest_main.a
pkg-config --print-errors --exact-version "1.14.0" gtest_main
test -f $PREFIX/lib/libgmock${SHLIB_EXT}
test ! -f $PREFIX/lib/libgmock.a
pkg-config --print-errors --exact-version "1.14.0" gmock
test -f $PREFIX/lib/libgmock_main${SHLIB_EXT}
test ! -f $PREFIX/lib/libgmock_main.a
pkg-config --print-errors --exact-version "1.14.0" gmock_main
test -f $PREFIX/include/gtest/gtest.h || (echo "gtest/gtest.h not found" && exit 1)
test -f $PREFIX/include/gmock/gmock.h || (echo "gmock/gmock.h not found" && exit 1)
exit 0
